/**************************************************************************************
Author:			David Szybala
Program:		Scene_Scale.ms
Date:			2/10/09
Description:	This script will scale all or part of a scene.
***************************************************************************************/

try (destroyDialog sceneScaleRollout) catch()
	
(--put script into local scope
	global sceneScaleRollout
	local sceneScaleIniFile = getDir #plugcfg + "\\SceneScale.ini"
	local sceneScaleRolloutPos

	rollout sceneScaleRollout "Scene Scale"
	(
		group "Preset"
		(
			dropdownlist presetList items:#("None","mm to cm","mm to in","cm to mm","cm to in","in to mm","in to cm") selection:1 height:9
		)--end group
		
		group "Scale"
		(
			label spinnerLabel "Percent:" align:#left across:3
			spinner spinnerPercent range:[0.01,10000.0,100.0] type:#float fieldWidth:50 align:#left
			label spinnerLabel2 "%"
		)--end group
		
		group "Misc"
		(
			checkbox selectionOnly "Selection Only"
			checkbox resetScaleCheck "Reset Scale" checked:true
			checkbox preserveParentCheck "Preserve Parenting"
			checkbox changeSystemUnit "Change System Units"
			dropdownlist systemUnitList items:#("inches","feet","miles","millimeters","centimeters","meters","kilometers") selection:1 height:9 
		)--end group
		
		button buttonScale "Rescale Scene" width:150
		
		on sceneScaleRollout moved pos do
			setIniSetting sceneScaleIniFile "Dialog" "Position" (pos as string)
			
		on presetList selected itemNumber do
		(
			case itemNumber of
			(
				1: spinnerPercent.value = 100.00
				2: spinnerPercent.value = 10.0
				3: spinnerPercent.value = 3.937
				4: spinnerPercent.value = 1000.0
				5: spinnerPercent.value = 39.37
				6: spinnerPercent.value = 2540.0
				7: spinnerPercent.value = 254.0
			)--end case
			
			if itemNumber == 1 then
				spinnerPercent.enabled = true
			else
				spinnerPercent.enabled = false
		)--end on
	
		on buttonScale pressed do
		(
			local currentObjects = #()
			local originalParents = #()
			local unitDisplayNames = #(#Dec_In,#Dec_Ft,#Ft_Dec_In,#Millimeters,#Centimeters,#Meters,#Kilometers)
			local systemUnitNames = #(#Inches,#Feet,#Miles,#Millimeters,#Centimeters,#Meters,#Kilometers)
			local dummyWorld = dummy boxsize:[100,100,100] position:[0,0,0] name:"sceneScaleDummy"
			local scaleValue = spinnerPercent.value * .01
			
			if selectionOnly.checked then
				currentObjects = selection as array
			else 
				currentObjects = objects as array
			
			clearSelection()
			
			if preserveParentCheck.checked do --create list of original parents
			(
				for current in currentObjects do
						originalParents[originalParents.count + 1] = current.parent
			)--end if
			
			for current in currentObjects do --parent objects to dummy
			(
				if current != dummyWorld do
					current.parent = dummyWorld
			)--end for
			
			scale dummyWorld [scaleValue,scaleValue,scaleValue] --scale dummy
			
			if resetScaleCheck.checked do resetScale dummyWorld --reset scale
			
			if preserveParentCheck.checked do --reparent objects
			(
				for i = 1 to currentObjects.count do
					currentObjects[i].parent = originalParents[i]
			)--end if
			
			delete dummyWorld --delete dummy after reparenting
			
			if changeSystemUnit.checked do --change system settings
			(			
				if systemUnitList.selection > 3 then
				(
					units.DisplayType = #Metric
					units.MetricType = unitDisplayNames[systemUnitList.selection]
				)--end if
				else
				(
					units.DisplayType = #US
					units.USType = unitDisplayNames[systemUnitList.selection]
				)--end else
				 
				units.SystemType = systemUnitNames[systemUnitList.selection]
			)	--end if	
			
			print "Scene scale complete."
		)--end on
	)--end rollout
	sceneScaleRolloutPos = execute (getIniSetting sceneScaleIniFile "Dialog" "Position")
	if sceneScaleRolloutPos == OK do sceneScaleRolloutPos = [100,100]
	if sceneScaleRolloutPos.x > sysinfo.desktopsize.x - 160 do sceneScaleRolloutPos.x = sysinfo.desktopsize.x - 165
	if sceneScaleRolloutPos.y > sysinfo.desktopsize.y - 310 do sceneScaleRolloutPos.y = sysinfo.desktopsize.y - 310
	if sceneScaleRolloutPos.x < 0 do sceneScaleRolloutPos.x = 0 
	if sceneScaleRolloutPos.y < 0 do sceneScaleRolloutPos.y = 0
	createDialog sceneScaleRollout 160 260 sceneScaleRolloutPos.x sceneScaleRolloutPos.y
)--end local scope